@@ -5,15 +5,17 @@
 #' @param x annmatrix object.
 #' @param pattern a regular expression used to select possible auto-completion names.
 #'
+#' @return A set of possible auto-completion names for row (\code{@}) or column (\code{$}) annotation fields.
+#'
 #' @author Karolis Koncevičius
 #' @name autocomplete
 #' @export
 .DollarNames.annmatrix <- function(x, pattern = "") {
-  findMatches(pattern, names(attr(x, ".annmatrix.cann")))
+  utils::findMatches(pattern, names(attr(x, ".annmatrix.cann")))
 }
 
 #' @rdname autocomplete
 #' @export
 .AtNames.annmatrix <- function(x, pattern = "") {
-  findMatches(pattern, names(attr(x, ".annmatrix.rann")))
+  utils::findMatches(pattern, names(attr(x, ".annmatrix.rann")))
 }
